==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/VolumeProjectionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface VolumeProjectionFluent<A extends io.fabric8.kubernetes.api.model.VolumeProjectionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildConfigMap instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ConfigMapProjection getConfigMap();
  public io.fabric8.kubernetes.api.model.ConfigMapProjection buildConfigMap();
  public A withConfigMap(io.fabric8.kubernetes.api.model.ConfigMapProjection configMap);
  public java.lang.Boolean hasConfigMap();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> withNewConfigMap();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> withNewConfigMapLike(io.fabric8.kubernetes.api.model.ConfigMapProjection item);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> editConfigMap();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> editOrNewConfigMap();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> editOrNewConfigMapLike(io.fabric8.kubernetes.api.model.ConfigMapProjection item);
  
  /**
   * This method has been deprecated, please use method buildDownwardAPI instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.DownwardAPIProjection getDownwardAPI();
  public io.fabric8.kubernetes.api.model.DownwardAPIProjection buildDownwardAPI();
  public A withDownwardAPI(io.fabric8.kubernetes.api.model.DownwardAPIProjection downwardAPI);
  public java.lang.Boolean hasDownwardAPI();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> withNewDownwardAPI();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> withNewDownwardAPILike(io.fabric8.kubernetes.api.model.DownwardAPIProjection item);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> editDownwardAPI();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> editOrNewDownwardAPI();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> editOrNewDownwardAPILike(io.fabric8.kubernetes.api.model.DownwardAPIProjection item);
  
  /**
   * This method has been deprecated, please use method buildSecret instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretProjection getSecret();
  public io.fabric8.kubernetes.api.model.SecretProjection buildSecret();
  public A withSecret(io.fabric8.kubernetes.api.model.SecretProjection secret);
  public java.lang.Boolean hasSecret();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> withNewSecret();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> withNewSecretLike(io.fabric8.kubernetes.api.model.SecretProjection item);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> editSecret();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> editOrNewSecret();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> editOrNewSecretLike(io.fabric8.kubernetes.api.model.SecretProjection item);
  
  /**
   * This method has been deprecated, please use method buildServiceAccountToken instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection getServiceAccountToken();
  public io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection buildServiceAccountToken();
  public A withServiceAccountToken(io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection serviceAccountToken);
  public java.lang.Boolean hasServiceAccountToken();
  public A withNewServiceAccountToken(java.lang.String audience,java.lang.Long expirationSeconds,java.lang.String path);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> withNewServiceAccountToken();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> withNewServiceAccountTokenLike(io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection item);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> editServiceAccountToken();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> editOrNewServiceAccountToken();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> editOrNewServiceAccountTokenLike(io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection item);
  public interface ConfigMapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent<io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<N>>{
    public N and();
    public N endConfigMap();
    
  }
  public interface DownwardAPINested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.DownwardAPIProjectionFluent<io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<N>>{
    public N and();
    public N endDownwardAPI();
    
  }
  public interface SecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretProjectionFluent<io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<N>>{
    public N and();
    public N endSecret();
    
  }
  public interface ServiceAccountTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ServiceAccountTokenProjectionFluent<io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<N>>{
    public N and();
    public N endServiceAccountToken();
    
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/VolumeProjectionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface VolumeProjectionFluent<A extends io.fabric8.kubernetes.api.model.VolumeProjectionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildConfigMap instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ConfigMapProjection getConfigMap();
  public io.fabric8.kubernetes.api.model.ConfigMapProjection buildConfigMap();
  public A withConfigMap(io.fabric8.kubernetes.api.model.ConfigMapProjection configMap);
  public java.lang.Boolean hasConfigMap();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> withNewConfigMap();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> withNewConfigMapLike(io.fabric8.kubernetes.api.model.ConfigMapProjection item);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> editConfigMap();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> editOrNewConfigMap();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<A> editOrNewConfigMapLike(io.fabric8.kubernetes.api.model.ConfigMapProjection item);
  
  /**
   * This method has been deprecated, please use method buildDownwardAPI instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.DownwardAPIProjection getDownwardAPI();
  public io.fabric8.kubernetes.api.model.DownwardAPIProjection buildDownwardAPI();
  public A withDownwardAPI(io.fabric8.kubernetes.api.model.DownwardAPIProjection downwardAPI);
  public java.lang.Boolean hasDownwardAPI();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> withNewDownwardAPI();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> withNewDownwardAPILike(io.fabric8.kubernetes.api.model.DownwardAPIProjection item);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> editDownwardAPI();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> editOrNewDownwardAPI();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<A> editOrNewDownwardAPILike(io.fabric8.kubernetes.api.model.DownwardAPIProjection item);
  
  /**
   * This method has been deprecated, please use method buildSecret instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretProjection getSecret();
  public io.fabric8.kubernetes.api.model.SecretProjection buildSecret();
  public A withSecret(io.fabric8.kubernetes.api.model.SecretProjection secret);
  public java.lang.Boolean hasSecret();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> withNewSecret();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> withNewSecretLike(io.fabric8.kubernetes.api.model.SecretProjection item);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> editSecret();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> editOrNewSecret();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<A> editOrNewSecretLike(io.fabric8.kubernetes.api.model.SecretProjection item);
  
  /**
   * This method has been deprecated, please use method buildServiceAccountToken instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection getServiceAccountToken();
  public io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection buildServiceAccountToken();
  public A withServiceAccountToken(io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection serviceAccountToken);
  public java.lang.Boolean hasServiceAccountToken();
  public A withNewServiceAccountToken(java.lang.String audience,java.lang.Long expirationSeconds,java.lang.String path);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> withNewServiceAccountToken();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> withNewServiceAccountTokenLike(io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection item);
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> editServiceAccountToken();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> editOrNewServiceAccountToken();
  public io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<A> editOrNewServiceAccountTokenLike(io.fabric8.kubernetes.api.model.ServiceAccountTokenProjection item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConfigMapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ConfigMapProjectionFluent<io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ConfigMapNested<N>>{
    public N and();
    public N endConfigMap();
    
  }
  public interface DownwardAPINested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.DownwardAPIProjectionFluent<io.fabric8.kubernetes.api.model.VolumeProjectionFluent.DownwardAPINested<N>>{
    public N and();
    public N endDownwardAPI();
    
  }
  public interface SecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretProjectionFluent<io.fabric8.kubernetes.api.model.VolumeProjectionFluent.SecretNested<N>>{
    public N and();
    public N endSecret();
    
  }
  public interface ServiceAccountTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ServiceAccountTokenProjectionFluent<io.fabric8.kubernetes.api.model.VolumeProjectionFluent.ServiceAccountTokenNested<N>>{
    public N and();
    public N endServiceAccountToken();
    
  }
  
}
